@@ -21,11 +21,18 @@ _get_ves()
 			/usr/sbin/vzlist -H -S -octid 2>/dev/null
 			/usr/sbin/vzlist -H -S -oname 2>/dev/null | $rm_empty
 			;;
-		stop|enter|exec*)
+		stop|enter|exec*|chkpnt)
 			# running CTs
 			/usr/sbin/vzlist -H -octid 2>/dev/null
 			/usr/sbin/vzlist -H -oname 2>/dev/null | $rm_empty
 			;;
+		restore)
+			# suspended CTs
+			(/usr/sbin/vzlist -HS -o status,ctid;
+			 /usr/sbin/vzlist -HS -o status,name) 2>/dev/null | \
+				grep '^suspended ' | \
+				sed 's/^suspended *//' | $rm_empty
+			;;
 		*)
 			# All CTs
 			/usr/sbin/vzlist -H -a -octid 2>/dev/null
@@ -60,7 +67,7 @@ _vzctl()
 		--dgramrcvbuf --oomguarpages --lockedpages --privvmpages \
 		--shmpages --numfile --numflock --numpty --numsiginfo \
 		--dcachesize --numiptent --physpages --swappages \
-		--cpuunits --cpulimit --cpus \
+		--cpuunits --cpulimit --cpus --cpumask \
 		--iptables --netdev_add --netdev_del --netif_add --netif_del \
 		--diskquota \
 		--diskspace --diskinodes --quotatime --quotaugidlimit \
@@ -119,8 +126,8 @@ _vzctl()
 			--ostemplate)
 				# get the template path from the vz.conf
 				local vztmpl=`grep ^TEMPLATE /etc/vz/vz.conf | cut -d "=" -f 2`
-				COMPREPLY=( $( compgen -W "$(command ls -1 $vztmpl/cache/*.tar.gz 2>/dev/null |
-						    sed -e "s#^$vztmpl/cache/##" -e 's#.tar.gz$##')" -- $cur ) )
+				COMPREPLY=( $( compgen -W "$(command ls $vztmpl/cache/*.tar{,.gz,.xz,.bz2} 2>/dev/null |
+						    sed -e "s#^$vztmpl/cache/##" -e 's#\.tar\.*[gbxz2]*$##')" -- $cur ) )
 
 				;;
 			--onboot|--disabled|--noatime|--diskquota)
